==> common-core-1.8.1-sources.jar: cn/featherfly/common/constant/Chars.java <==

package cn.featherfly.common.constant;

/**
 * <p>
 * 基本字符的常量
 * </p>
 *
 * @author zhongj
 */
public interface Chars {
    /**
     * 符号 ~
     */
    String NOT_B = "~";
    /**
     * 符号 !
     */
    String NOT_L = "!";
    /**
     * 符号 @
     */
    String AT = "@";
    /**
     * 符号 #
     */
    String SHARP = "#";
    /**
     * 符号 $
     */
    String DOLLAR = "$";
    /**
     * 符号 %
     */
    String MOD = "%";
    /**
     * 符号 ^
     */
    String BXOR = "^";
    /**
     * 符号 &amp;
     */
    String AMP = "&";
    /**
     * 符号 *
     */
    String STAR = "*";
    /**
     * 符号 (
     */
    String PAREN_L = "(";
    /**
     * 符号 )
     */
    String PAREN_R = ")";
    /**
     * 符号 _
     */
    String UNDER_LINE = "_";
    /**
     * 符号 -
     */
    String MINUS = "-";
    /**
     * 符号 +
     */
    String PLUS = "+";
    /**
     * 符号 =
     */
    String EQ = "=";
    /**
     * 符号 {
     */
    String CURLY_L = "{";
    /**
     * 符号 }
     */
    String CURLY_R = "}";
    /**
     * 符号 [
     */
    String BRACK_L = "[";
    /**
     * 符号 ]
     */
    String BRACK_R = "]";
    /**
     * 符号 |
     */
    String OR = "|";
    /**
     * 符号 \
     */
    String TL = "\\";
    /**
     * 符号 :
     */
    String COLON = ":";
    /**
     * 符号 ;
     */
    String SEMI = ";";
    /**
     * 符号 "
     */
    String DQM = "\"";
    /**
     * 符号 '
     */
    String QM = "'";
    /**
     * 符号&lt;
     */
    String LT = "<";
    /**
     * 符号 &gt;
     */
    String GT = ">";
    /**
     * 符号 .
     */
    String DOT = ".";
    /**
     * 符号 ,
     */
    String COMMA = ",";
    /**
     * 符号 ?
     */
    String QUESTION = "?";
    /**
     * 符号 /
     */
    String DIV = "/";
    /**
     * 空格
     */
    String SPACE = " ";
    /**
     * 空字符串
     */
    String EMPTY_STR = "";
    /**
     * 换行符号
     */
    String NEW_LINE = "\n";
    /**
     * 回车符号
     */
    String CARRIAGE_RETURN = "\r";
    /**
     * 制表符
     */
    String TAB = "\t";
    /**
     * 数字 0
     */
    int ZERO = 0;
    /**
     * 数字 1
     */
    int ONE = 1;
    /**
     * 数字 2
     */
    int TWO = 2;
    /**
     * 数字 3
     */
    int THREE = 3;
    /**
     * 数字 4
     */
    int FOUR = 4;
    /**
     * 数字 5
     */
    int FIVE = 5;
    /**
     * 数字 6
     */
    int SIX = 6;
    /**
     * 数字 7
     */
    int SEVEN = 7;
    /**
     * 数字 8
     */
    int EIGHT = 8;
    /**
     * 数字 9
     */
    int NINE = 9;
    /**
     * 大写 A
     */
    String A_UPPER = "A";
    /**
     * 大写 B
     */
    String B_UPPER = "B";
    /**
     * 大写 C
     */
    String C_UPPER = "C";
    /**
     * 大写 D
     */
    String D_UPPER = "D";
    /**
     * 大写 E
     */
    String E_UPPER = "E";
    /**
     * 大写 F
     */
    String F_UPPER = "F";
    /**
     * 大写 G
     */
    String G_UPPER = "G";
    /**
     * 大写 H
     */
    String H_UPPER = "H";
    /**
     * 大写 I
     */
    String I_UPPER = "I";
    /**
     * 大写 J
     */
    String J_UPPER = "J";
    /**
     * 大写 K
     */
    String K_UPPER = "K";
    /**
     * 大写 L
     */
    String L_UPPER = "L";
    /**
     * 大写 M
     */
    String M_UPPER = "M";
    /**
     * 大写 N
     */
    String N_UPPER = "N";
    /**
     * 大写 O
     */
    String O_UPPER = "O";
    /**
     * 大写 P
     */
    String P_UPPER = "P";
    /**
     * 大写 Q
     */
    String Q_UPPER = "Q";
    /**
     * 大写 R
     */
    String R_UPPER = "R";
    /**
     * 大写 S
     */
    String S_UPPER = "S";
    /**
     * 大写 T
     */
    String T_UPPER = "T";
    /**
     * 大写 U
     */
    String U_UPPER = "U";
    /**
     * 大写 V
     */
    String V_UPPER = "V";
    /**
     * 大写 W
     */
    String W_UPPER = "W";
    /**
     * 大写 X
     */
    String X_UPPER = "X";
    /**
     * 大写 Y
     */
    String Y_UPPER = "Y";
    /**
     * 大写 Z
     */
    String Z_UPPER = "Z";
    /**
     * 小写 a
     */
    String A_LOWER = "a";
    /**
     * 小写 b
     */
    String B_LOWER = "b";
    /**
     * 小写 c
     */
    String C_LOWER = "c";
    /**
     * 小写 d
     */
    String D_LOWER = "d";
    /**
     * 小写 e
     */
    String E_LOWER = "e";
    /**
     * 小写 f
     */
    String F_LOWER = "f";
    /**
     * 小写 g
     */
    String G_LOWER = "g";
    /**
     * 小写 h
     */
    String H_LOWER = "h";
    /**
     * 小写 i
     */
    String I_LOWER = "i";
    /**
     * 小写 j
     */
    String J_LOWER = "j";
    /**
     * 小写 k
     */
    String K_LOWER = "k";
    /**
     * 小写 l
     */
    String L_LOWER = "l";
    /**
     * 小写 m
     */
    String M_LOWER = "m";
    /**
     * 小写 n
     */
    String N_LOWER = "n";
    /**
     * 小写 o
     */
    String O_LOWER = "o";
    /**
     * 小写 p
     */
    String P_LOWER = "p";
    /**
     * 小写 q
     */
    String Q_LOWER = "q";
    /**
     * 小写 r
     */
    String R_LOWER = "r";
    /**
     * 小写 s
     */
    String S_LOWER = "s";
    /**
     * 小写 t
     */
    String T_LOWER = "t";
    /**
     * 小写 u
     */
    String U_LOWER = "u";
    /**
     * 小写 v
     */
    String V_LOWER = "v";
    /**
     * 小写 w
     */
    String W_LOWER = "w";
    /**
     * 小写 x
     */
    String X_LOWER = "x";
    /**
     * 小写 y
     */
    String Y_LOWER = "y";
    /**
     * 小写 z
     */
    String Z_LOWER = "z";
    /**
     * 符号 ~
     */
    char NOT_B_CHAR = '~';
    /**
     * 符号 !
     */
    char NOT_L_CHAR = '!';
    /**
     * 符号 @
     */
    char AT_CHAR = '@';
    /**
     * 符号 #
     */
    char SHARP_CHAR = '#';
    /**
     * 符号 $
     */
    char DOLLAR_CHAR = '$';
    /**
     * 符号 %
     */
    char MOD_CHAR = '%';
    /**
     * 符号 ^
     */
    char BXOR_CHAR = '^';
    /**
     * 符号 &amp;
     */
    char AMP_CHAR = '&';
    /**
     * 符号 *
     */
    char STAR_CHAR = '*';
    /**
     * 符号 (
     */
    char PAREN_L_CHAR = '(';
    /**
     * 符号 )
     */
    char PAREN_R_CHAR = ')';
    /**
     * 符号 _
     */
    char UNDER_LINE_CHAR = '_';
    /**
     * 符号 -
     */
    char MINUS_CHAR = '-';
    /**
     * 符号 +
     */
    char PLUS_CHAR = '+';
    /**
     * 符号 =
     */
    char EQ_CHAR = '=';
    /**
     * 符号 {
     */
    char CURLY_L_CHAR = '{';
    /**
     * 符号 }
     */
    char CURLY_R_CHAR = '}';
    /**
     * 符号 [
     */
    char BRACK_L_CHAR = '[';
    /**
     * 符号 ]
     */
    char BRACK_R_CHAR = ']';
    /**
     * 符号 |
     */
    char OR_CHAR = '|';
    /**
     * 符号 \
     */
    char TL_CHAR = '\\';
    /**
     * 符号 :
     */
    char COLON_CHAR = ':';
    /**
     * 符号 ;
     */
    char SEMI_CHAR = ';';
    /**
     * 符号 "
     */
    char DQM_CHAR = '"';
    /**
     * 符号 '
     */
    char QM_CHAR = '\'';
    /**
     * 符号&lt;
     */
    char LT_CHAR = '<';
    /**
     * 符号 &gt;
     */
    char GT_CHAR = '>';
    /**
     * 符号 .
     */
    char DOT_CHAR = '.';
    /**
     * 符号 ,
     */
    char COMMA_CHAR = ',';
    /**
     * 符号 ?
     */
    char QUESTION_CHAR = '?';
    /**
     * 符号 /
     */
    char DIV_CHAR = '/';
    /**
     * 空格
     */
    char SPACE_CHAR = ' ';

    /**
     * 大写 A
     */
    char A_UPPER_CHAR = 'A';
    /**
     * 大写 B
     */
    char B_UPPER_CHAR = 'B';
    /**
     * 大写 C
     */
    char C_UPPER_CHAR = 'C';
    /**
     * 大写 D
     */
    char D_UPPER_CHAR = 'D';
    /**
     * 大写 E
     */
    char E_UPPER_CHAR = 'E';
    /**
     * 大写 F
     */
    char F_UPPER_CHAR = 'F';
    /**
     * 大写 G
     */
    char G_UPPER_CHAR = 'G';
    /**
     * 大写 H
     */
    char H_UPPER_CHAR = 'H';
    /**
     * 大写 I
     */
    char I_UPPER_CHAR = 'I';
    /**
     * 大写 J
     */
    char J_UPPER_CHAR = 'J';
    /**
     * 大写 K
     */
    char K_UPPER_CHAR = 'K';
    /**
     * 大写 L
     */
    char L_UPPER_CHAR = 'L';
    /**
     * 大写 M
     */
    char M_UPPER_CHAR = 'M';
    /**
     * 大写 N
     */
    char N_UPPER_CHAR = 'N';
    /**
     * 大写 O
     */
    char O_UPPER_CHAR = 'O';
    /**
     * 大写 P
     */
    char P_UPPER_CHAR = 'P';
    /**
     * 大写 Q
     */
    char Q_UPPER_CHAR = 'Q';
    /**
     * 大写 R
     */
    char R_UPPER_CHAR = 'R';
    /**
     * 大写 S
     */
    char S_UPPER_CHAR = 'S';
    /**
     * 大写 T
     */
    char T_UPPER_CHAR = 'T';
    /**
     * 大写 U
     */
    char U_UPPER_CHAR = 'U';
    /**
     * 大写 V
     */
    char V_UPPER_CHAR = 'V';
    /**
     * 大写 W
     */
    char W_UPPER_CHAR = 'W';
    /**
     * 大写 X
     */
    char X_UPPER_CHAR = 'X';
    /**
     * 大写 Y
     */
    char Y_UPPER_CHAR = 'Y';
    /**
     * 大写 Z
     */
    char Z_UPPER_CHAR = 'Z';
    /**
     * 小写 a
     */
    char A_LOWER_CHAR = 'a';
    /**
     * 小写 b
     */
    char B_LOWER_CHAR = 'b';
    /**
     * 小写 c
     */
    char C_LOWER_CHAR = 'c';
    /**
     * 小写 d
     */
    char D_LOWER_CHAR = 'd';
    /**
     * 小写 e
     */
    char E_LOWER_CHAR = 'e';
    /**
     * 小写 f
     */
    char F_LOWER_CHAR = 'f';
    /**
     * 小写 g
     */
    char G_LOWER_CHAR = 'g';
    /**
     * 小写 h
     */
    char H_LOWER_CHAR = 'h';
    /**
     * 小写 i
     */
    char I_LOWER_CHAR = 'i';
    /**
     * 小写 j
     */
    char J_LOWER_CHAR = 'j';
    /**
     * 小写 k
     */
    char K_LOWER_CHAR = 'k';
    /**
     * 小写 l
     */
    char L_LOWER_CHAR = 'l';
    /**
     * 小写 m
     */
    char M_LOWER_CHAR = 'm';
    /**
     * 小写 n
     */
    char N_LOWER_CHAR = 'n';
    /**
     * 小写 o
     */
    char O_LOWER_CHAR = 'o';
    /**
     * 小写 p
     */
    char P_LOWER_CHAR = 'p';
    /**
     * 小写 q
     */
    char Q_LOWER_CHAR = 'q';
    /**
     * 小写 r
     */
    char R_LOWER_CHAR = 'r';
    /**
     * 小写 s
     */
    char S_LOWER_CHAR = 's';
    /**
     * 小写 t
     */
    char T_LOWER_CHAR = 't';
    /**
     * 小写 u
     */
    char U_LOWER_CHAR = 'u';
    /**
     * 小写 v
     */
    char V_LOWER_CHAR = 'v';
    /**
     * 小写 w
     */
    char W_LOWER_CHAR = 'w';
    /**
     * 小写 x
     */
    char X_LOWER_CHAR = 'x';
    /**
     * 小写 y
     */
    char Y_LOWER_CHAR = 'y';
    /**
     * 小写 z
     */
    char Z_LOWER_CHAR = 'z';

    /**
     * 换行符号
     */
    char NEW_LINEZ_CHAR = '\n';
    /**
     * 回车符号
     */
    char CARRIAGE_RETURN_CHAR = '\r';
    /**
     * 制表符
     */
    char TAB_CHAR = '\t';
}

==> common-core-1.8.4-sources.jar: cn/featherfly/common/constant/Chars.java <==

package cn.featherfly.common.constant;

/**
 * <p>
 * 基本字符的常量
 * </p>
 *
 * @author zhongj
 */
public interface Chars {
    /**
     * 符号 ~
     */
    String NOT_B = "~";
    /**
     * 符号 !
     */
    String NOT_L = "!";
    /**
     * 符号 @
     */
    String AT = "@";
    /**
     * 符号 #
     */
    String SHARP = "#";
    /**
     * 符号 $
     */
    String DOLLAR = "$";
    /**
     * 符号 %
     */
    String MOD = "%";
    /**
     * 符号 ^
     */
    String BXOR = "^";
    /**
     * 符号 &amp;
     */
    String AMP = "&";
    /**
     * 符号 *
     */
    String STAR = "*";
    /**
     * 符号 (
     */
    String PAREN_L = "(";
    /**
     * 符号 )
     */
    String PAREN_R = ")";
    /**
     * 符号 _
     */
    String UNDER_LINE = "_";
    /**
     * 符号 -
     */
    String MINUS = "-";
    /**
     * 符号 +
     */
    String PLUS = "+";
    /**
     * 符号 =
     */
    String EQ = "=";
    /**
     * 符号 {
     */
    String CURLY_L = "{";
    /**
     * 符号 }
     */
    String CURLY_R = "}";
    /**
     * 符号 [
     */
    String BRACK_L = "[";
    /**
     * 符号 ]
     */
    String BRACK_R = "]";
    /**
     * 符号 |
     */
    String OR = "|";
    /**
     * 符号 \
     */
    String TL = "\\";
    /**
     * 符号 :
     */
    String COLON = ":";
    /**
     * 符号 ;
     */
    String SEMI = ";";
    /**
     * 符号 "
     */
    String DQM = "\"";
    /**
     * 符号 '
     */
    String QM = "'";
    /**
     * 符号&lt;
     */
    String LT = "<";
    /**
     * 符号 &gt;
     */
    String GT = ">";
    /**
     * 符号 .
     */
    String DOT = ".";
    /**
     * 符号 ,
     */
    String COMMA = ",";
    /**
     * 符号 ?
     */
    String QUESTION = "?";
    /**
     * 符号 /
     */
    String DIV = "/";
    /**
     * 空格
     */
    String SPACE = " ";
    /**
     * 空字符串
     */
    String EMPTY_STR = "";
    /**
     * 换行符号
     */
    String NEW_LINE = "\n";
    /**
     * 回车符号
     */
    String CARRIAGE_RETURN = "\r";
    /**
     * 制表符
     */
    String TAB = "\t";
    /**
     * 数字 0
     */
    int ZERO = 0;
    /**
     * 数字 1
     */
    int ONE = 1;
    /**
     * 数字 2
     */
    int TWO = 2;
    /**
     * 数字 3
     */
    int THREE = 3;
    /**
     * 数字 4
     */
    int FOUR = 4;
    /**
     * 数字 5
     */
    int FIVE = 5;
    /**
     * 数字 6
     */
    int SIX = 6;
    /**
     * 数字 7
     */
    int SEVEN = 7;
    /**
     * 数字 8
     */
    int EIGHT = 8;
    /**
     * 数字 9
     */
    int NINE = 9;
    /**
     * 数字 0
     */
    String ZERO_STR = "0";
    /**
     * 数字 1
     */
    String ONE_STR = "1";
    /**
     * 数字 2
     */
    String TWO_STR = "2";
    /**
     * 数字 3
     */
    String THREE_STR = "3";
    /**
     * 数字 4
     */
    String FOUR_STR = "4";
    /**
     * 数字 5
     */
    String FIVE_STR = "5";
    /**
     * 数字 6
     */
    String SIX_STR = "6";
    /**
     * 数字 7
     */
    String SEVEN_STR = "7";
    /**
     * 数字 8
     */
    String EIGHT_STR = "8";
    /**
     * 数字 9
     */
    String NINE_STR = "9";
    /**
     * 数字 0
     */
    char ZERO_CHAR = '0';
    /**
     * 数字 1
     */
    char ONE_CHAR = '1';
    /**
     * 数字 2
     */
    char TWO_CHAR = '2';
    /**
     * 数字 3
     */
    char THREE_CHAR = '3';
    /**
     * 数字 4
     */
    char FOUR_CHAR = '4';
    /**
     * 数字 5
     */
    char FIVE_CHAR = '5';
    /**
     * 数字 6
     */
    char SIX_CHAR = '6';
    /**
     * 数字 7
     */
    char SEVEN_CHAR = '7';
    /**
     * 数字 8
     */
    char EIGHT_CHAR = '8';
    /**
     * 数字 9
     */
    char NINE_CHAR = '9';
    /**
     * 大写 A
     */
    String A_UPPER = "A";
    /**
     * 大写 B
     */
    String B_UPPER = "B";
    /**
     * 大写 C
     */
    String C_UPPER = "C";
    /**
     * 大写 D
     */
    String D_UPPER = "D";
    /**
     * 大写 E
     */
    String E_UPPER = "E";
    /**
     * 大写 F
     */
    String F_UPPER = "F";
    /**
     * 大写 G
     */
    String G_UPPER = "G";
    /**
     * 大写 H
     */
    String H_UPPER = "H";
    /**
     * 大写 I
     */
    String I_UPPER = "I";
    /**
     * 大写 J
     */
    String J_UPPER = "J";
    /**
     * 大写 K
     */
    String K_UPPER = "K";
    /**
     * 大写 L
     */
    String L_UPPER = "L";
    /**
     * 大写 M
     */
    String M_UPPER = "M";
    /**
     * 大写 N
     */
    String N_UPPER = "N";
    /**
     * 大写 O
     */
    String O_UPPER = "O";
    /**
     * 大写 P
     */
    String P_UPPER = "P";
    /**
     * 大写 Q
     */
    String Q_UPPER = "Q";
    /**
     * 大写 R
     */
    String R_UPPER = "R";
    /**
     * 大写 S
     */
    String S_UPPER = "S";
    /**
     * 大写 T
     */
    String T_UPPER = "T";
    /**
     * 大写 U
     */
    String U_UPPER = "U";
    /**
     * 大写 V
     */
    String V_UPPER = "V";
    /**
     * 大写 W
     */
    String W_UPPER = "W";
    /**
     * 大写 X
     */
    String X_UPPER = "X";
    /**
     * 大写 Y
     */
    String Y_UPPER = "Y";
    /**
     * 大写 Z
     */
    String Z_UPPER = "Z";
    /**
     * 小写 a
     */
    String A_LOWER = "a";
    /**
     * 小写 b
     */
    String B_LOWER = "b";
    /**
     * 小写 c
     */
    String C_LOWER = "c";
    /**
     * 小写 d
     */
    String D_LOWER = "d";
    /**
     * 小写 e
     */
    String E_LOWER = "e";
    /**
     * 小写 f
     */
    String F_LOWER = "f";
    /**
     * 小写 g
     */
    String G_LOWER = "g";
    /**
     * 小写 h
     */
    String H_LOWER = "h";
    /**
     * 小写 i
     */
    String I_LOWER = "i";
    /**
     * 小写 j
     */
    String J_LOWER = "j";
    /**
     * 小写 k
     */
    String K_LOWER = "k";
    /**
     * 小写 l
     */
    String L_LOWER = "l";
    /**
     * 小写 m
     */
    String M_LOWER = "m";
    /**
     * 小写 n
     */
    String N_LOWER = "n";
    /**
     * 小写 o
     */
    String O_LOWER = "o";
    /**
     * 小写 p
     */
    String P_LOWER = "p";
    /**
     * 小写 q
     */
    String Q_LOWER = "q";
    /**
     * 小写 r
     */
    String R_LOWER = "r";
    /**
     * 小写 s
     */
    String S_LOWER = "s";
    /**
     * 小写 t
     */
    String T_LOWER = "t";
    /**
     * 小写 u
     */
    String U_LOWER = "u";
    /**
     * 小写 v
     */
    String V_LOWER = "v";
    /**
     * 小写 w
     */
    String W_LOWER = "w";
    /**
     * 小写 x
     */
    String X_LOWER = "x";
    /**
     * 小写 y
     */
    String Y_LOWER = "y";
    /**
     * 小写 z
     */
    String Z_LOWER = "z";
    /**
     * 符号 ~
     */
    char NOT_B_CHAR = '~';
    /**
     * 符号 !
     */
    char NOT_L_CHAR = '!';
    /**
     * 符号 @
     */
    char AT_CHAR = '@';
    /**
     * 符号 #
     */
    char SHARP_CHAR = '#';
    /**
     * 符号 $
     */
    char DOLLAR_CHAR = '$';
    /**
     * 符号 %
     */
    char MOD_CHAR = '%';
    /**
     * 符号 ^
     */
    char BXOR_CHAR = '^';
    /**
     * 符号 &amp;
     */
    char AMP_CHAR = '&';
    /**
     * 符号 *
     */
    char STAR_CHAR = '*';
    /**
     * 符号 (
     */
    char PAREN_L_CHAR = '(';
    /**
     * 符号 )
     */
    char PAREN_R_CHAR = ')';
    /**
     * 符号 _
     */
    char UNDER_LINE_CHAR = '_';
    /**
     * 符号 -
     */
    char MINUS_CHAR = '-';
    /**
     * 符号 +
     */
    char PLUS_CHAR = '+';
    /**
     * 符号 =
     */
    char EQ_CHAR = '=';
    /**
     * 符号 {
     */
    char CURLY_L_CHAR = '{';
    /**
     * 符号 }
     */
    char CURLY_R_CHAR = '}';
    /**
     * 符号 [
     */
    char BRACK_L_CHAR = '[';
    /**
     * 符号 ]
     */
    char BRACK_R_CHAR = ']';
    /**
     * 符号 |
     */
    char OR_CHAR = '|';
    /**
     * 符号 \
     */
    char TL_CHAR = '\\';
    /**
     * 符号 :
     */
    char COLON_CHAR = ':';
    /**
     * 符号 ;
     */
    char SEMI_CHAR = ';';
    /**
     * 符号 "
     */
    char DQM_CHAR = '"';
    /**
     * 符号 '
     */
    char QM_CHAR = '\'';
    /**
     * 符号&lt;
     */
    char LT_CHAR = '<';
    /**
     * 符号 &gt;
     */
    char GT_CHAR = '>';
    /**
     * 符号 .
     */
    char DOT_CHAR = '.';
    /**
     * 符号 ,
     */
    char COMMA_CHAR = ',';
    /**
     * 符号 ?
     */
    char QUESTION_CHAR = '?';
    /**
     * 符号 /
     */
    char DIV_CHAR = '/';
    /**
     * 空格
     */
    char SPACE_CHAR = ' ';

    /**
     * 大写 A
     */
    char A_UPPER_CHAR = 'A';
    /**
     * 大写 B
     */
    char B_UPPER_CHAR = 'B';
    /**
     * 大写 C
     */
    char C_UPPER_CHAR = 'C';
    /**
     * 大写 D
     */
    char D_UPPER_CHAR = 'D';
    /**
     * 大写 E
     */
    char E_UPPER_CHAR = 'E';
    /**
     * 大写 F
     */
    char F_UPPER_CHAR = 'F';
    /**
     * 大写 G
     */
    char G_UPPER_CHAR = 'G';
    /**
     * 大写 H
     */
    char H_UPPER_CHAR = 'H';
    /**
     * 大写 I
     */
    char I_UPPER_CHAR = 'I';
    /**
     * 大写 J
     */
    char J_UPPER_CHAR = 'J';
    /**
     * 大写 K
     */
    char K_UPPER_CHAR = 'K';
    /**
     * 大写 L
     */
    char L_UPPER_CHAR = 'L';
    /**
     * 大写 M
     */
    char M_UPPER_CHAR = 'M';
    /**
     * 大写 N
     */
    char N_UPPER_CHAR = 'N';
    /**
     * 大写 O
     */
    char O_UPPER_CHAR = 'O';
    /**
     * 大写 P
     */
    char P_UPPER_CHAR = 'P';
    /**
     * 大写 Q
     */
    char Q_UPPER_CHAR = 'Q';
    /**
     * 大写 R
     */
    char R_UPPER_CHAR = 'R';
    /**
     * 大写 S
     */
    char S_UPPER_CHAR = 'S';
    /**
     * 大写 T
     */
    char T_UPPER_CHAR = 'T';
    /**
     * 大写 U
     */
    char U_UPPER_CHAR = 'U';
    /**
     * 大写 V
     */
    char V_UPPER_CHAR = 'V';
    /**
     * 大写 W
     */
    char W_UPPER_CHAR = 'W';
    /**
     * 大写 X
     */
    char X_UPPER_CHAR = 'X';
    /**
     * 大写 Y
     */
    char Y_UPPER_CHAR = 'Y';
    /**
     * 大写 Z
     */
    char Z_UPPER_CHAR = 'Z';
    /**
     * 小写 a
     */
    char A_LOWER_CHAR = 'a';
    /**
     * 小写 b
     */
    char B_LOWER_CHAR = 'b';
    /**
     * 小写 c
     */
    char C_LOWER_CHAR = 'c';
    /**
     * 小写 d
     */
    char D_LOWER_CHAR = 'd';
    /**
     * 小写 e
     */
    char E_LOWER_CHAR = 'e';
    /**
     * 小写 f
     */
    char F_LOWER_CHAR = 'f';
    /**
     * 小写 g
     */
    char G_LOWER_CHAR = 'g';
    /**
     * 小写 h
     */
    char H_LOWER_CHAR = 'h';
    /**
     * 小写 i
     */
    char I_LOWER_CHAR = 'i';
    /**
     * 小写 j
     */
    char J_LOWER_CHAR = 'j';
    /**
     * 小写 k
     */
    char K_LOWER_CHAR = 'k';
    /**
     * 小写 l
     */
    char L_LOWER_CHAR = 'l';
    /**
     * 小写 m
     */
    char M_LOWER_CHAR = 'm';
    /**
     * 小写 n
     */
    char N_LOWER_CHAR = 'n';
    /**
     * 小写 o
     */
    char O_LOWER_CHAR = 'o';
    /**
     * 小写 p
     */
    char P_LOWER_CHAR = 'p';
    /**
     * 小写 q
     */
    char Q_LOWER_CHAR = 'q';
    /**
     * 小写 r
     */
    char R_LOWER_CHAR = 'r';
    /**
     * 小写 s
     */
    char S_LOWER_CHAR = 's';
    /**
     * 小写 t
     */
    char T_LOWER_CHAR = 't';
    /**
     * 小写 u
     */
    char U_LOWER_CHAR = 'u';
    /**
     * 小写 v
     */
    char V_LOWER_CHAR = 'v';
    /**
     * 小写 w
     */
    char W_LOWER_CHAR = 'w';
    /**
     * 小写 x
     */
    char X_LOWER_CHAR = 'x';
    /**
     * 小写 y
     */
    char Y_LOWER_CHAR = 'y';
    /**
     * 小写 z
     */
    char Z_LOWER_CHAR = 'z';

    /**
     * 换行符号
     */
    char NEW_LINEZ_CHAR = '\n';
    /**
     * 回车符号
     */
    char CARRIAGE_RETURN_CHAR = '\r';
    /**
     * 制表符
     */
    char TAB_CHAR = '\t';
}
